@@ -23,11 +23,16 @@
 #include <Plasma/Containment>
 #include <Plasma/Corona>
 
-#include <QDebug>
 #include <QQuickItem>
 
-ContainmentInterface::ContainmentInterface(QObject *parent) : QObject(parent),
-    m_applet(0)
+// FIXME HACK TODO: Unfortunately we have no choice but to hard-code a list of
+// applets we know to expose the correct interface right now -- this is slated
+// for replacement with some form of generic service.
+QStringList ContainmentInterface::m_knownTaskManagers = QStringList() << QLatin1String("org.kde.plasma.taskmanager")
+    << QLatin1String("org.kde.plasma.icontasks")
+    << QLatin1String("org.kde.plasma.expandingiconstaskmanager");
+
+ContainmentInterface::ContainmentInterface(QObject *parent) : QObject(parent)
 {
 }
 
@@ -35,16 +40,14 @@ ContainmentInterface::~ContainmentInterface()
 {
 }
 
-void ContainmentInterface::setApplet(QObject* plasmoid)
+bool ContainmentInterface::mayAddLauncher(QObject *appletInterface, ContainmentInterface::Target target, const QString &entryPath)
 {
-    if (plasmoid) {
-         m_applet = plasmoid->property("_plasma_applet").value<Plasma::Applet *>();
+    if (!appletInterface) {
+        return false;
     }
-}
 
-bool ContainmentInterface::mayAddLauncher(ContainmentInterface::Target target, const QString &entryPath)
-{
-    Plasma::Containment *containment = m_applet->containment();
+    Plasma::Applet *applet = appletInterface->property("_plasma_applet").value<Plasma::Applet *>();
+    Plasma::Containment *containment = applet->containment();
 
     if (!containment) {
         return false;
@@ -80,7 +83,7 @@ bool ContainmentInterface::mayAddLauncher(ContainmentInterface::Target target, c
                 const Plasma::Applet *taskManager = 0;
 
                 foreach(const Plasma::Applet *applet, containment->applets()) {
-                    if (applet->pluginInfo().pluginName() == QLatin1String("org.kde.plasma.taskmanager")) {
+                    if (m_knownTaskManagers.contains(applet->pluginInfo().pluginName())) {
                         taskManager = applet;
 
                         break;
@@ -112,9 +115,14 @@ bool ContainmentInterface::mayAddLauncher(ContainmentInterface::Target target, c
     return false;
 }
 
-void ContainmentInterface::addLauncher(ContainmentInterface::Target target, const QString &entryPath)
+void ContainmentInterface::addLauncher(QObject *appletInterface, ContainmentInterface::Target target, const QString &entryPath)
 {
-    Plasma::Containment *containment = m_applet->containment();
+    if (!appletInterface) {
+        return;
+    }
+
+    Plasma::Applet *applet = appletInterface->property("_plasma_applet").value<Plasma::Applet *>();
+    Plasma::Containment *containment = applet->containment();
 
     if (!containment) {
         return;
@@ -176,7 +184,7 @@ void ContainmentInterface::addLauncher(ContainmentInterface::Target target, cons
                 const Plasma::Applet *taskManager = 0;
 
                 foreach(const Plasma::Applet *applet, containment->applets()) {
-                    if (applet->pluginInfo().pluginName() == QLatin1String("org.kde.plasma.taskmanager")) {
+                    if (m_knownTaskManagers.contains(applet->pluginInfo().pluginName())) {
                         taskManager = applet;
 
                         break;
