@@ -30,9 +30,8 @@
 #include <kcomponentdata.h>
 #include <KDebug>
 #include <KWallet/Wallet>
-#include <KGlobal>
 #include <kcmultidialog.h>
-#include <klocale.h>
+#include <KLocalizedString>
 #include <KStringHandler>
 #include <KMessageBox>
 
@@ -41,18 +40,8 @@ using namespace Attica;
 KdePlatformDependent::KdePlatformDependent()
     : m_config(KSharedConfig::openConfig("atticarc")), m_accessManager(0), m_wallet(0)
 {
-    // when a plain Qt application loads this plugin, it needs a valid KGlobal object
-    if (!KGlobal::hasMainComponent()) {
-        KComponentData componentData("attica_kde");
-    }
-
-//     TODO: re-enable, see http://community.kde.org/Frameworks/Porting_Notes
-//     KLocale* locale = KGlobal::locale();
-//     if (locale) {
-//         locale->insertCatalog("attica_kde");
-//     }
-
-    m_accessManager = new KIO::Integration::AccessManager(this);
+    // FIXME: Investigate how to not leak this instance witohut crashing.
+    m_accessManager = new KIO::Integration::AccessManager(0);
 }
 
 KdePlatformDependent::~KdePlatformDependent()
