@@ -80,7 +80,7 @@ KColorCm::KColorCm(QWidget *parent, const QVariantList &)
       m_previousSchemeItem(0)
 {
     KAboutData* about = new KAboutData(
-        QStringLiteral("kcmcolors"), QString(), i18n("Colors"), QString(),
+        QStringLiteral("kcmcolors"), i18n("Colors"), QStringLiteral("1.0"), QString(),
         KAboutLicense::GPL,
         i18n("(c) 2007 Matthew Woehlke")
     );
